.. transmission-rpc documentation master file, created by
   sphinx-quickstart on Fri Oct  5 09:29:21 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Client
============================================

.. autoclass:: transmission_rpc.client.Client
    :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents: